MzEnigma
===========================
A package implementing the operation of several enigma models (see `crytomuseum`_)
and common methods (see `cryptool`_) for their analysis


Installing
----------

The package is a pure python package.
To work the package requires `networkx`_ for the manipulation of complex networks.

Download the package using
::

    pip install mzEnigma

.. _crytomuseum: https://www.cryptomuseum.com/crypto/enigma
.. _cryptool: https://www.cryptool.org/en/documentation/ctbook/    
.. _networkx: https://networkx.org/
        
